!++++++++++++++++++++++++++++++++++++++++++++++
!! This file is part of an Object Oriented Programming
!! in Fortran 2003 tutorial series.
!! The tutorial series was originally posted online at
!! http://dannyvanpoucke.be/fortran-tutorials-en/
!! and a pdf of the most recent
!! version can be found on ArXiv .
!!
!! (c) Dr. Dr. Danny E.P. Vanpoucke 2015
!!
!----------------------------------------------
!+++++++++++++++++++++++++++++++++++++++++++++++
!>\brief Small support module doing the IO.
!<----------------------------------------------
module IO
    implicit none
    private

    public :: writeOpiniondynamics, writeOpiniondynamics3DGrace

contains
    !++++++++++++++++++++++++++++++++++++++++
    !>\brief Quick and dirty subroutine
    !! to write the opinion histogram data to a textfile.
    !<---------------------------------------
    subroutine writeOpiniondynamics(od,mesh,na,nsim,nrun,filename)
        real :: od(:,:)
        integer, intent(in) :: mesh, na, nsim, nrun
        character(len=*), intent(in) :: filename

        integer :: nr

        open(unit=20,file=trim(filename),status="REPLACE",action="WRITE")
        do nr=1,mesh
            write(20,*) nr," ",od(nr,:)
        end do
        close(20)

    end subroutine writeOpiniondynamics
    !++++++++++++++++++++++++++++++++++++++++
    !>\brief Quick and dirty simulation of 3D graphics with xmgrace line-plots.
    !<---------------------------------------
    subroutine writeOpiniondynamics3DGrace(od,mesh,na,nsim,nrun,filename)
        real :: od(:,:)
        integer, intent(in) :: mesh, na, nsim, nrun

        integer :: nr, nr2,shft
        real :: shftx
        character(len=*), intent(in) :: filename

        open(unit=20,file=trim(filename),status="REPLACE",action="WRITE")
        do nr2=nsim,1,-1
            shft=(nr2-1)*25
            shftx=nr2*0.1
            do nr=1,mesh
                write(20,'(f6.2,a,f10.3)') nr+shftx," ",od(nr,nr2)+shft
            end do
            write(20,*) " "
        end do
        close(20)

    end subroutine writeOpiniondynamics3DGrace

end module IO
